==> flutter_meedu-5.2.0.tar.gz: README.md <==
<p align="center">
  <a href="https://pub.dev/packages/flutter_meedu"><img alt="pub version" src="https://img.shields.io/pub/v/flutter_meedu?include_prereleases&label=flutter_meedu"/></a>

  <img style={{marginLeft:10}} alt="last commit" src="https://img.shields.io/github/last-commit/darwin-morocho/flutter-meedu"/>
   <a style={{marginLeft:10}} href="https://codecov.io/gh/darwin-morocho/flutter-meedu">
  <img src="https://codecov.io/gh/darwin-morocho/flutter-meedu/branch/master/graph/badge.svg?token=VM29N1NHWJ"/>
  </a>
  <a style={{marginLeft:10}} href="https://discord.gg/rV4bPsdefj">
  <img src="https://img.shields.io/static/v1?label=Discord&message=Server&color=1565c0"/>
  </a>
  <img style={{marginLeft:10}} alt="license" src="https://img.shields.io/github/license/darwin-morocho/flutter-meedu"/>
  <img style={{marginLeft:10}} alt="stars" src="https://img.shields.io/github/stars/darwin-morocho/flutter-meedu?style=social"/>
</p>

## What is **flutter_meedu**?
Is a **powerful** State Managment, Dependency Injection, Reactive programming and Navigation for Flutter apps.

## Features
- A State Managment for simple and complex states.

  flutter_meedu helps you to manage the state of your flutter app without boilerplate, code generators or InheritedWidget.

- Navigate without BuildContext.
 
  Navigate to your app without a custom Page class, a custom MaterialApp.

- Simple dependecy injection.

- Reactive programming.

- Easy to test.

**FULL DOCUMENTATION**  👉  https://flutter.meedu.app




## Spanish course with unit testing and widget testing

You can find a complete video course (**Spanish**) about how to use **flutter_meedu** [here](https://meedu.app/curso/flutter-gestion-de-estados-con-meedu)

==> flutter_meedu-7.0.0-dev.1.tar.gz: README.md <==
<p align="center">
  <a href="https://pub.dev/packages/flutter_meedu"><img alt="pub version" src="https://img.shields.io/pub/v/flutter_meedu?include_prereleases&label=flutter_meedu"/></a>

  <img style={{marginLeft:10}} alt="last commit" src="https://img.shields.io/github/last-commit/darwin-morocho/flutter-meedu"/>
   <a style={{marginLeft:10}} href="https://codecov.io/gh/darwin-morocho/flutter-meedu">
  <img src="https://codecov.io/gh/darwin-morocho/flutter-meedu/branch/master/graph/badge.svg?token=VM29N1NHWJ"/>
  </a>
  <a style={{marginLeft:10}} href="https://discord.gg/rV4bPsdefj">
  <img src="https://img.shields.io/static/v1?label=Discord&message=Server&color=1565c0"/>
  </a>
  <img style={{marginLeft:10}} alt="license" src="https://img.shields.io/github/license/darwin-morocho/flutter-meedu"/>
  <img style={{marginLeft:10}} alt="stars" src="https://img.shields.io/github/stars/darwin-morocho/flutter-meedu?style=social"/>
</p>

## What is **flutter_meedu**?
Is a **powerful** State Management, Dependency Injection, Reactive programming and Navigation for Flutter apps.

## Features
- A State Management for simple and complex states.

  flutter_meedu helps you to manage the state of your flutter app without boilerplate, code generators or InheritedWidget.

- Navigate without BuildContext.
 
  Navigate to your app without a custom Page class, a custom MaterialApp.

- Simple dependecy injection.

- Reactive programming.

- Easy to test.

**FULL DOCUMENTATION**  👉  https://flutter.meedu.app




## Spanish course with unit testing and widget testing

You can find a complete video course (**Spanish**) about how to use **flutter_meedu** [here](https://meedu.app/curso/flutter-gestion-de-estados-con-meedu)
